@@ -1,4 +1,4 @@
-/* $Id: the-linux-kernel.h 88816 2013-09-09 10:14:21Z fmehnert $ */
+/* $Id: the-linux-kernel.h 91595 2014-01-14 10:15:25Z fmehnert $ */
 /** @file
  * IPRT - Include all necessary headers for the Linux kernel.
  */
@@ -150,6 +150,10 @@
 # define DEFINE_WAIT(name) DECLARE_WAITQUEUE(name, current)
 #endif
 
+#ifndef __GFP_NOWARN
+# define __GFP_NOWARN 0
+#endif
+
 /*
  * 2.4 / early 2.6 compatibility wrappers
  */
